@@ -12,29 +12,6 @@ import java.util.*;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-/*
- * jmx4perl - WAR Agent for exporting JMX via JSON
- *
- * Copyright (C) 2009 Roland Huß, roland@cpan.org
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *
- * A commercial license is available as well. Please contact roland@cpan.org for
- * further details.
- */
-
 /**
  * Factory for creating {@link org.jmx4perl.JmxRequest}s
  *
@@ -97,22 +74,10 @@ final public class JmxRequestFactory {
     static public JmxRequest createRequestFromUrl(String pPathInfo, Map<String,String[]> pParameterMap) {
         JmxRequest request = null;
         try {
-            String pathInfo = pPathInfo;
+            if (pPathInfo != null && pPathInfo.length() > 0) {
 
-            // If no pathinfo is given directly, we look for a query parameter named 'p'.
-            // This variant is helpful, if there are problems with the server mangling
-            // up the pathinfo (e.g. for security concerns, often '/','\',';' and other are not
-            // allowed in econded form within the pathinfo)
-            if (pPathInfo == null || pPathInfo.length() == 0 || pathInfo.matches("^/+$")) {
-                String[] vals = pParameterMap.get("p");
-                if (vals != null && vals.length > 0) {
-                    pathInfo = vals[0];
-                }
-            }
-
-            if (pathInfo != null && pathInfo.length() > 0) {
                 // Get all path elements as a reverse stack
-                Stack<String> elements = extractElementsFromPath(pathInfo);
+                Stack<String> elements = extractElementsFromPath(pPathInfo);
                 Type type = extractType(elements.pop());
 
                 Processor processor = PROCESSOR_MAP.get(type);
@@ -128,10 +93,8 @@ final public class JmxRequestFactory {
 
                 // Setup JSON representation
                 extractParameters(request,pParameterMap);
-                return request;
-            } else {
-                throw new IllegalArgumentException("No pathinfo given and no query parameter 'p'");
             }
+            return request;
         } catch (NoSuchElementException exp) {
             throw new IllegalArgumentException("Invalid path info " + pPathInfo,exp);
         } catch (MalformedObjectNameException e) {
