@@ -32,18 +32,11 @@ package org.jmx4perl;
  */
 public final class Version {
 
-    private static final String VERSION = "0.65.0";
-
-    // Version of the 
-    private static final String PROTOCOL = "3";
+    private static final String VERSION = "0.65.0.M1";
 
     private Version() {}
 
-    public static String getAgentVersion() {
+    public static String getVersion() {
         return VERSION;
     }
-
-    public static String getProtocolVersion() {
-        return PROTOCOL;
-    }
 }
