@@ -100,12 +100,7 @@ configuration if you are using the agent servlet as a proxy, e.g.
 =cut
 
 # HTTP Parameters to be used for transmitting the request
-my %PARAM_MAPPING = (
-                     "max_depth" => "maxDepth",
-                     "max_list_size" => "maxCollectionSize",
-                     "max_objects" => "maxObjects"
-                    );
-
+my @PARAMS = ("maxDepth","maxCollectionSize","maxObjects","ignoreErrors");
 
 # Init called by parent package within 'new' for specific initialization. See
 # above for the parameters recognized
@@ -193,7 +188,7 @@ sub request {
 sub _to_http_request {
     my $self = shift;
     my @reqs = @_;
-    if (@reqs == 1 && !$reqs[0]->get("target")) {
+    if ($self->_use_GET_request(\@reqs)) {
         # Old, rest-style
         my $url = $self->request_url($reqs[0]);
         return HTTP::Request->new(GET => $url);
@@ -201,12 +196,25 @@ sub _to_http_request {
         my $url = $self->cfg('url') || croak "No URL provided";
         $url .= "/" unless $url =~ m|/$|;
         my $request = HTTP::Request->new(POST => $url);
-        my $content = to_json(\@reqs, { convert_blessed => 1 });
+        my $content = to_json(@reqs > 1 ? \@reqs : $reqs[0], { convert_blessed => 1 });
+        #print Dumper($reqs[0],$content);
         $request->content($content);
         return $request;
     }    
 }
 
+sub _use_GET_request {
+    my $self = shift;
+    my $reqs = shift;
+    if (@$reqs == 1) {
+        my $req = $reqs->[0];
+        # For proxy configs and explicite set POST request, get is not used
+        return !defined($req->get("target")) && lc($req->get("method")) ne "post" ;
+    } else {
+        return 0;
+    }
+}
+
 # Create one or more response objects for a given request
 sub _from_http_response {
     my $self = shift;
@@ -284,7 +292,8 @@ sub _validate_response {
           ( 
            status => $http_resp->code,
            content => $json_error ? $http_resp->content : $json_resp,
-           error => $json_error ? $self->_prepare_http_error_text($http_resp) : $json_resp->{error},
+           error => $json_error ? $self->_prepare_http_error_text($http_resp) : 
+           ref($json_resp) eq "ARRAY" ? join "\n",  map { $_->{error} } @$json_resp : $json_resp->{error},
            stacktrace => ref($json_resp) eq "ARRAY" ? $self->_extract_stacktraces($json_resp) : $json_resp->{stacktrace}
           );        
     }
@@ -316,15 +325,20 @@ sub request_url {
         $req .= $self->_extract_path($request->get("path"));
     } elsif ($type eq EXEC) {
         $req .= "/" . $self->_escape($request->get("operation"));
-        $req .= "/" . $self->_escape($self->_null_escape($_)) for @{$request->get("arguments")};
+        for my $arg (@{$request->get("arguments")}) {
+            # Array refs are sticked together via ","
+            my $a = ref($arg) eq "ARRAY" ? join ",",@{$arg} : $arg;
+            $req .= "/" . $self->_escape($self->_null_escape($a));
+        }
     } elsif ($type eq SEARCH) {
         # Nothing further to append.
     }
     # Squeeze multiple slashes
     $req =~ s|/{2,}|/|g;
+    #print "R: $req\n";
     my @params;
-    for my $k (keys %PARAM_MAPPING) {
-        push @params, $PARAM_MAPPING{$k} . "=" . $request->get($k)
+    for my $k (@PARAMS) {
+        push @params, $k . "=" . $request->get($k)
           if $request->get($k);
     }
     $req .= "?" . join("&",@params) if @params;
@@ -351,7 +365,9 @@ sub _escape {
     my $input = shift;
     my $opts = { @_ };
     $input =~ s|(/+)|"/" . ('-' x length($1)) . "/"|eg;
-    $input =~ s|-/$|+/|; # The last slash needs a special escape
+    $input =~ s|-/$|+/|; # The last slash needs a special escape    
+    $input =~ s|^/-|/^|; # as well as the first slash
+
     return URI::Escape::uri_escape_utf8($input,"^A-Za-z0-9\-_.!~*'()/");   # Added "/" to
                                                               # default
                                                               # set. See L<URI>
